---
title: GRASS GIS 8.5.0dev Reference Manual: Parser standard options index
author: GRASS Development Team
---


## Parser standard options
| answer | description | descriptions | gisprompt | key | key_desc | label | multiple | options | required | type |
| ------ | ----------- | ------------ | --------- | --- | -------- | ----- | -------- | ------- | -------- | ---- |
| G_OPT_DB_SQL |  | Example: select * from towns where population > 10000 |  |  | sql | sql_query | SQL SELECT statement |  |  | NO | TYPE_STRING |
| G_OPT_DB_WHERE |  | Example: income < 1000 and population >= 10000 |  | old,sql_query,sql_query | where | sql_query | WHERE conditions of SQL statement without 'where' keyword |  |  | NO | TYPE_STRING |
| G_OPT_DB_TABLE |  | Name of attribute table |  | old,dbtable,dbtable | table | name |  | NO |  | NO | TYPE_STRING |
| G_OPT_DB_DRIVER |  | Name of database driver |  | old,dbdriver,dbdriver | driver | name |  | NO |  | NO | TYPE_STRING |
| G_OPT_DB_DATABASE |  | Name of database |  | old,dbname,dbname | database | name |  | NO |  | NO | TYPE_STRING |
| G_OPT_DB_SCHEMA |  | Do not use this option if schemas  are not supported by driver/database server |  |  | schema | name | Database schema | NO |  | NO | TYPE_STRING |
| G_OPT_DB_COLUMN |  | Name of attribute column |  | old,dbcolumn,dbcolumn | column | name |  | NO |  | NO | TYPE_STRING |
| G_OPT_DB_COLUMNS |  | Name of attribute column(s |  | old,dbcolumn,dbcolumn | columns | name |  | YES |  | NO | TYPE_STRING |
| G_OPT_DB_KEYCOLUMN | GV_KEY_COLUMN | Must refer to an integer column |  |  | key | name | Name of key column | NO |  | NO | TYPE_STRING |
| G_OPT_I_GROUP |  | Name of input imagery group |  | old,group,group | group | name |  |  |  | YES | TYPE_STRING |
| G_OPT_I_SUBGROUP |  | Name of input imagery subgroup |  | old,subgroup,subgroup | subgroup | name |  |  |  | YES | TYPE_STRING |
| G_OPT_MEMORYMB | 300 | Cache size for raster rows |  |  | memory | memory in MB | Maximum memory to be used (in MB | NO |  | NO | TYPE_INTEGER |
| G_OPT_R_INPUT |  | Name of input raster map |  | old,cell,raster | input | name |  |  |  | YES | TYPE_STRING |
| G_OPT_R_INPUTS |  | Name of input raster map(s |  | old,cell,raster | input | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_R_OUTPUT |  | Name for output raster map |  | new,cell,raster | output | name |  |  |  | YES | TYPE_STRING |
| G_OPT_R_OUTPUTS |  | Name for output raster map(s |  | new,cell,raster | output | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_R_MAP |  | Name of raster map |  | old,cell,raster | map | name |  |  |  | YES | TYPE_STRING |
| G_OPT_R_MAPS |  | Name of raster map(s |  | old,cell,raster | map | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_R_BASE |  | Name of base raster map |  | old,cell,raster | base | name |  |  |  | YES | TYPE_STRING |
| G_OPT_R_COVER |  | Name of cover raster map |  | old,cell,raster | cover | name |  |  |  | YES | TYPE_STRING |
| G_OPT_R_ELEV |  | Name of input elevation raster map |  | old,cell,raster | elevation | name |  |  |  | YES | TYPE_STRING |
| G_OPT_R_ELEVS |  | Name of input elevation raster map(s |  | old,cell,raster | elevation | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_R_TYPE |  | Storage type for resultant raster map |  |  | type |  | Type of raster map to be created | NO | CELL,FCELL,DCELL | YES | TYPE_STRING |
| G_OPT_R_INTERP_TYPE |  | Sampling interpolation method |  |  | method |  |  |  | nearest,bilinear,bicubic | NO | TYPE_STRING |
| G_OPT_R_BASENAME_INPUT |  | Name of input basename raster map(s |  | old,cell,raster | input | basename |  | NO |  | YES | TYPE_STRING |
| G_OPT_R_BASENAME_OUTPUT |  | Name for output basename raster map(s |  | new,cell,raster | output | basename |  | NO |  | YES | TYPE_STRING |
| G_OPT_R3_INPUT |  | Name of input 3D raster map |  | old,grid3,raster_3d | input | name |  |  |  | YES | TYPE_STRING |
| G_OPT_R3_INPUTS |  | Name of input 3D raster map(s |  | old,grid3,raster_3d | input | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_R3_OUTPUT |  | Name for output 3D raster map |  | new,grid3,raster_3d | output | name |  |  |  | YES | TYPE_STRING |
| G_OPT_R3_MAP |  | Name of 3D raster map |  | old,grid3,raster_3d | map | name |  |  |  | YES | TYPE_STRING |
| G_OPT_R3_MAPS |  | Name of 3D raster map(s |  | old,grid3,raster_3d | map | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_R3_TYPE | default | Data type used in the output raster3d map |  |  | type |  |  | NO | default,double,float | NO | TYPE_STRING |
| G_OPT_R3_PRECISION | default | Number of digits used as mantissa in the internal map storage,  0 -23 for float, 0 - 52 for double, max or default |  |  | precision |  |  | NO |  | NO | TYPE_STRING |
| G_OPT_R3_COMPRESSION | default | The compression method used in the output raster3d map |  |  | compression |  |  | NO | default,zip,none | NO | TYPE_STRING |
| G_OPT_R3_TILE_DIMENSION | default | The dimensions of the tiles used in the output  raster3d map (XxYxZ or default: 16x16x8 |  |  | tiledimension | XxYxZ |  | NO |  | NO | TYPE_STRING |
| G_OPT_V_INPUT |  | Or data source for direct OGR access |  | old,vector,vector | input | name | Name of input vector map |  |  | YES | TYPE_STRING |
| G_OPT_V_INPUTS |  | Or data source(s) for direct OGR access |  | old,vector,vector | input | name | Name of input vector map(s | YES |  | YES | TYPE_STRING |
| G_OPT_V_OUTPUT |  | Name for output vector map |  | new,vector,vector | output | name |  |  |  | YES | TYPE_STRING |
| G_OPT_V_MAP |  | Or data source for direct OGR access |  | old,vector,vector | map | name | Name of vector map |  |  | YES | TYPE_STRING |
| G_OPT_V_MAPS |  | Name of vector map(s |  | old,vector,vector | map | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_V_TYPE | point,line,boundary,centroid,area | Input feature type |  |  | type |  |  | YES | point,line,boundary,centroid,area | NO | TYPE_STRING |
| G_OPT_V3_TYPE | point,line,boundary,centroid,area,face,kernel | Input feature type |  |  | type |  |  | YES | point,line,boundary,centroid,area,face,kernel | NO | TYPE_STRING |
| G_OPT_V_FIELD | 1 | Vector features can have category values in different layers.  This number determines which layer to use.  When used with direct OGR access this is the layer name. |  | old,layer,layer | layer |  | Layer number or name |  |  | NO | TYPE_STRING |
| G_OPT_V_FIELD_ALL | -1 | A single vector map can be connected to multiple database  tables. This number determines which table to use.  When used with direct OGR access this is the layer name. |  | old,layer_all,layer | layer |  | Layer number or name ('-1' for all layers |  |  | NO | TYPE_STRING |
| G_OPT_V_CAT |  | Category value |  | old,cat,cats | cat |  |  |  |  | NO | TYPE_INTEGER |
| G_OPT_V_CATS |  | Example: 1,3,7-9,13 |  | old,cats,cats | cats | range | Category values |  |  | NO | TYPE_STRING |
| G_OPT_V_ID |  | Feature id |  |  | id |  |  |  |  | NO | TYPE_INTEGER |
| G_OPT_V_IDS |  | Example: 1,3,7-9,13 |  |  | ids | range | Feature ids |  |  | NO | TYPE_STRING |
| G_OPT_F_INPUT |  | Name of input file |  | old,file,file | input | name |  |  |  | YES | TYPE_STRING |
| G_OPT_F_BIN_INPUT |  | Name of input file |  | old,bin,file | input | name |  |  |  | YES | TYPE_STRING |
| G_OPT_F_OUTPUT |  | Name for output file |  | new,file,file | output | name |  |  |  | YES | TYPE_STRING |
| G_OPT_F_SEP | pipe | Special characters: pipe, comma, space, tab, newline |  | old,separator,separator | separator | character | Field separator |  |  | NO | TYPE_STRING |
| G_OPT_C | DEFAULT_FG_COLOR | Either a standard color name or R:G:B triplet |  | old,color,color | color | name | Color |  |  | NO | TYPE_STRING |
| G_OPT_CN | DEFAULT_FG_COLOR | Either a standard color name, R:G:B triplet, or \none\ |  | old,color_none,color | color | name | Color |  |  | NO | TYPE_STRING |
| G_OPT_C_FORMAT | hex | Color format for output values. |  |  | color_format | name | Color format | NO | rgb,hex,hsv,triplet | YES | TYPE_STRING |
| G_OPT_M_DIR |  | Name of input directory |  | old,dir,dir | input | name |  |  |  | YES | TYPE_STRING |
| G_OPT_M_UNITS |  | Units |  |  | units |  |  | NO | miles,feet,meters,kilometers,acres,hectares | NO | TYPE_STRING |
| G_OPT_M_DATATYPE |  | Data type(s |  |  | type | datatype |  | YES |  | YES | TYPE_STRING |
| G_OPT_M_MAPSET |  | '.' for current mapset |  | old,mapset,mapset | mapset | name | Name of mapset (default: current search path | NO |  | NO | TYPE_STRING |
| G_OPT_M_LOCATION |  | Project name (not path to project |  | old,location,location | project | name | Project (location) name | NO |  | NO | TYPE_STRING |
| G_OPT_M_DBASE |  | Default: path to the current GRASS GIS database |  | old,dbase,dbase | dbase | path | GRASS GIS database directory | NO |  | NO | TYPE_STRING |
| G_OPT_M_COORDS |  | Coordinates |  | old,coords,coords | coordinates | east,north |  | NO |  | NO | TYPE_DOUBLE |
| G_OPT_M_COLR |  | Name of color table | G_color_rules_description_type( | old,colortable,colortable | color | style |  |  | G_color_rules_options( | NO | TYPE_STRING |
| G_OPT_M_NULL_VALUE |  | String representing NULL value |  |  | null_value | string |  | NO |  | NO | TYPE_STRING |
| G_OPT_M_REGION |  | Name of saved region |  | old,windows,region | region | name |  |  |  | NO | TYPE_STRING |
| G_OPT_M_NPROCS | 1 | Number of threads for parallel computing |  |  | nprocs |  |  | NO |  | NO | TYPE_INTEGER |
| G_OPT_STDS_INPUT |  | Name of the input space time dataset |  | old,stds,stds | input | name |  |  |  | YES | TYPE_STRING |
| G_OPT_STDS_INPUTS |  | Name of the input space time datasets |  | old,stds,stds | inputs | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_STDS_OUTPUT |  | Name of the output space time dataset |  | new,stds,stds | output | name |  |  |  | YES | TYPE_STRING |
| G_OPT_STRDS_INPUT |  | Name of the input space time raster dataset |  | old,strds,strds | input | name |  |  |  | YES | TYPE_STRING |
| G_OPT_STRDS_INPUTS |  | Name of the input space time raster datasets |  | old,strds,strds | inputs | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_STRDS_OUTPUT |  | Name of the output space time raster dataset |  | new,strds,strds | output | name |  |  |  | YES | TYPE_STRING |
| G_OPT_STRDS_OUTPUTS |  | Name of the output space time raster datasets |  | new,strds,strds | outputs | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_STVDS_INPUT |  | Name of the input space time vector dataset |  | old,stvds,stvds | input | name |  |  |  | YES | TYPE_STRING |
| G_OPT_STVDS_INPUTS |  | Name of the input space time vector datasets |  | old,stvds,stvds | inputs | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_STVDS_OUTPUT |  | Name of the output space time vector dataset |  | new,stvds,stvds | output | name |  |  |  | YES | TYPE_STRING |
| G_OPT_STR3DS_INPUT |  | Name of the input space time raster3d dataset |  | old,str3ds,str3ds | input | name |  |  |  | YES | TYPE_STRING |
| G_OPT_STR3DS_INPUTS |  | Name of the input space time raster3d datasets |  | old,str3ds,str3ds | inputs | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_STR3DS_OUTPUT |  | Name of the output space time raster3d dataset |  | new,str3ds,str3ds | output | name |  |  |  | YES | TYPE_STRING |
| G_OPT_STDS_TYPE | strds | Type of the input space time dataset |  |  | type | name |  |  | strds,stvds,str3ds | NO | TYPE_STRING |
| G_OPT_MAP_INPUT |  | Name of the input map |  | old,map,map | map | name |  |  |  | YES | TYPE_STRING |
| G_OPT_MAP_INPUTS |  | Name of the input maps |  | old,map,map | maps | name |  | YES |  | YES | TYPE_STRING |
| G_OPT_MAP_TYPE | raster | Type of the input map |  |  | type | name |  |  | raster,vector,raster_3d | NO | TYPE_STRING |
| G_OPT_T_TYPE | absolute | The temporal type of the space time dataset |  |  | temporaltype | name |  |  | absolute,relative | NO | TYPE_STRING |
| G_OPT_T_WHERE |  | Example: start_time > '2001-01-01 12:30:00' |  |  | where | sql_query | WHERE conditions of SQL statement without 'where'  keyword used in the temporal GIS framework |  |  | NO | TYPE_STRING |
| G_OPT_T_SAMPLE | start | The method to be used for sampling the input dataset |  |  | sampling | name |  | YES | start,during,overlap,contain,equal,follows,precedes | NO | TYPE_STRING |
| G_OPT_F_FORMAT | plain |  | plain;Plain text output; json;JSON (JavaScript Object Notation |  | format | name | Output format |  | plain,json | YES | TYPE_STRING |